# -*- coding: utf-8 -*-
"""
############################################################################################################
#############################                     EPSILON                      #############################
#############################             Reader_Epsilon_Wind_Tunnel           #############################
############################################################################################################

# Abstract:
This python code is a module of the "Epsilon Aero Data" plugin that reads the variables from the output of
Reader_Epsilon_Wind_Tunnel source.


# Disclaimer:
This plugin was developed for research purposes and released under GNU GPL V3 license without any guarantee
of any kind, either express or implied. Its use for teaching, research and industrial applications is allowed
under the strict responsibility of the user. The authors of this plugin are not responsible for any damages
or errors related to the use of the plugin.
"""


############################################################################################################
############################################### MODULES LOAD ###############################################
############################################################################################################

# We load the Python and Paraview standard modules:
import numpy as np
import vtk
from vtk.numpy_interface import algorithms as algs


############################################################################################################
################################### ELSA TECPLOT BINARY READER FUNCTION ####################################
############################################################################################################

def Reader_Epsilon_Wind_Tunnel(INPUT,R,CvGas,CpGas,Ps0,Rho0,Ts0,Pt0,V0):
    
    # Reading aero data from Fluent file:
	POINTS = INPUT.Points   									# It takes the points coordinates
	Vx = INPUT.PointData["Vx"]                              	# X-velocity component [m/s]
	Vy = INPUT.PointData["Vy"]                              	# Y-velocity component [m/s]	
	Vz = INPUT.PointData["Vz"]									# Z-velocity component [m/s]
	V = algs.sqrt(Vx**2+Vy**2+Vz**2)
	Isoenergetic = INPUT.FieldData["Isoenergetic"]
	
	# If static and total pressure data is available at the input (Multihole probe), it calculates Ps,Ts and Rho. Otherwise (PIV) these parameters are roughly estimated
	if INPUT.GetPointData().HasArray("Ps")==0:	
		Ps = Pt0-0.5*Rho0*V**2 				# Rough approximation valid only outside the wake
		Rho = Rho0*Vx/Vx  					# Incompressibility is assumed
		Ts = Ts0 + (0.5*(V0**2-V**2)/1005)
		#Ps = Rho*R*Ts
		print ""
		print "# PIV: Epsilon V2.0 assumes incompressible/isoenergetic flow"
		print "# PIV: Epsilon V2.0 do not provide Ps from PIV velocity data. The user must ignore any variable requiring Ps"

	else:
		Ps = INPUT.PointData["Ps"]
		print ""
		
		if Isoenergetic == 0:
			Gamma = CpGas/CvGas
			Pt = INPUT.PointData["Pt"] 
			M = algs.sqrt((2/(Gamma-1))*((Pt/Ps)**((Gamma-1)/Gamma)-1))
			a = V/M
			Ts = a**2/(Gamma*R)
			print "# MULTI-HOLE PROBE: non-isoenergetic flow --> Ts and Rho are estimated from Pt and Ps"
			
		if Isoenergetic ==1:
			Ts = Ts0 + (0.5*(V0**2-V**2)/1005)
			print "# MULTI-HOLE PROBE: isoenergetic flow --> Ts calculated from velocity and Tt"
			
		Rho = Ps/(R*Ts)



	MU_LAM = (0.000001458*Ts**1.5)/(Ts+110.4)   					# Two-coefficient Sutherland equation
	MU_TURB = 0*MU_LAM  											# No turbulence data is provided by experimental data
	MU_EFF = MU_LAM + MU_TURB
	Prt = 0.7    
	Keff = CpGas*((MU_LAM/0.7)+(MU_TURB/Prt))
	
	return POINTS,Vx,Vy,Vz,Ps,Ts,Rho,MU_LAM,MU_TURB,MU_EFF,Keff