# -*- coding: utf-8 -*-
"""
############################################################################################################
#############################                     EPSILON                      #############################
#############################                 Open Foam reader                 #############################
############################################################################################################

# Abstract:
This python code is a module of the "Epsilon Aero Data" plugin that reads data from Open Foam files.


# Disclaimer:
This plugin was developed for research purposes and released under GNU GPL V3 license without any guarantee
of any kind, either express or implied. Its use for teaching, research and industrial applications is allowed
under the strict responsibility of the user. The authors of this plugin are not responsible for any damages
or errors related to the use of the plugin.
"""


############################################################################################################
############################################### MODULES LOAD ###############################################
############################################################################################################

# We load the Python and Paraview standard modules:
import numpy as np
import vtk
from vtk.numpy_interface import algorithms as algs


############################################################################################################
######################################## FLUENT CAS READER FUNCTION ########################################
############################################################################################################

def Reader_Open_Foam(INPUT,R,CvGas,CpGas,Ps0,Pt0,Rho0,Ts0,V0,TypeOfParameter):
	import numpy as np

	# Reading aero data from Open Foam file:
	POINTS = INPUT.Points   										# It takes the points coordinates
	Vx = INPUT.PointData["U"][:,0]									# Velocity component along X-axis [m/s]	
	Vy = INPUT.PointData["U"][:,1]									# Velocity component along Y-axis [m/s]	
	Vz = INPUT.PointData["U"][:,2]									# Velocity component along Z-axis [m/s]	
	V = algs.sqrt(Vx**2+Vy**2+Vz**2)
	print ""
	
	# Read static pressure data:
	if algs.min(INPUT.GetPointData().GetArray("p"))<0:                                   # This check if "p" array contains negative values
		print "# OPEN FOAM: Static pressure input is relative to atmosphere. A conversion to absolute static pressure is made" 
		if TypeOfParameter == 1:
			print "# OPEN FOAM: Upstream reference static pressure used for conversion"                 
			Ps = INPUT.PointData["p"]+Ps0                                                    # Ps array is calculated from loaded data 
		if TypeOfParameter == 0: 
			print "# OPEN FOAM: Upstream reference total pressure used for conversion"                 
			Ps = INPUT.PointData["p"]+Pt0                                                    # Ps array is calculated from loaded data 
	else:
		Ps = INPUT.PointData["p"]                                                        # If the array contains absolute pressure values, then it reads the array data directly from input
  

	# Read static temperature data:
	if INPUT.GetPointData().HasArray("t")==0:                                           # This check if "t" array does not exists in the input 
		print "# OPEN FOAM: Static Temperature array is not available in the input data"          # It means that TEMPERATURE array does not exists (It may happen when energy equation is not activated in the RANS solution)
		print "# OPEN FOAM: Static Temperature data is reconstructed by considering an isoenergetic flow"
		Ts = Ts0 + (0.5*(V0**2-V**2)/1005)
	else:
		Ts = INPUT.PointData["t"]                                                       # If the array exists, then reads the array data directly from input
		
	Rho = Ps/(R*Ts)	 

	MU_LAM = (0.000001458*Ts**1.5)/(Ts+110.4)   					# Molecular viscosity [Kg/m*s]: Two-coefficient Sutherland equation
	MU_TURB = INPUT.PointData["nut"]    							# Turbulent viscosity [Kg/m*s]
	MU_EFF = MU_LAM + MU_TURB    									# Effective viscosity
	
		
	# Effective dissipation:
	Prt = 0.7     #IMPORTANT --> A STRONG HYPOTESIS IS MADE HERE (Pr=0.7) because no Prandtl number data available in OpenFoam file format
	Keff = CpGas*((MU_LAM/0.7)+(MU_TURB/Prt))

	return POINTS,Vx,Vy,Vz,Ps,Ts,Rho,MU_LAM,MU_TURB,MU_EFF,Keff