# -*- coding: utf-8 -*-
"""
############################################################################################################
#############################                     EPSILON                      #############################
#############################                TAU tecplot reader                #############################
############################################################################################################

# Abstract:
This python code is a module of the "Epsilon Aero Data" plugin that reads some variables from a TAU Tecplot file.


# Disclaimer:
This plugin was developed for research purposes and released under GNU GPL V3 license without any guarantee
of any kind, either express or implied. Its use for teaching, research and industrial applications is allowed
under the strict responsibility of the user. The authors of this plugin are not responsible for any damages
or errors related to the use of the plugin.
"""


############################################################################################################
############################################### MODULES LOAD ###############################################
############################################################################################################

# We load the Python and Paraview standard modules:
import numpy as np
import vtk
from vtk.numpy_interface import algorithms as algs


############################################################################################################
######################################## TAU Tecplot READER FUNCTION #######################################
############################################################################################################

def Reader_TAU_Tecplot(INPUT,R,CvGas,CpGas,Ps0,Rho0,Ts0):


	# Reading aero data from TAU file:
	POINTS = INPUT.Points   																	# It takes the points coordinates
	Vx = INPUT.PointData["x_velocity"] 															# Speed component along x-axis [m/s]
	print ""
	
	# Read Y_VELOCITY data:
	if INPUT.GetPointData().HasArray("y_velocity")==0:                           				# This check if "Y_VELOCITY" array does not exists in the input                
		print "# TAU: You are loading a 2D data (No Y_VELOCITY data available)"  				# It means that Y_VELOCITY array does not exists 
		Vy = 0*Vx                                                                				# If the array does not exists,it creates a null vector
	else:
		Vy = INPUT.PointData["y_velocity"]                                       				# If the array exists, then reads the array data directly from input
    
    
    # Read Z_VELOCITY data:
	if INPUT.GetPointData().HasArray("z_velocity")==0:                           				# This check if "Z_VELOCITY" array does not  exists in the input                
		print "# TAU: You are loading a 2D data (No Z_VELOCITY data available)"       			# It means that Z_VELOCITY array does not exists 
		Vz = 0*Vx
	else:
		Vz = INPUT.PointData["z_velocity"]                                       				# If the array exists, then reads the array data directly from input

		
	# Read static pressure data:
	if algs.min(INPUT.GetPointData().GetArray("pressure"))<0:                                   # This check if "PRESSURE" array contains negative values
		print "# TAU: Static pressure input is relative to atmosphere. A conversion to absolute static pressure is made"                         
		Ps = INPUT.PointData["pressure"]+Ps0                                                    # PRESSURE array is calculated from loaded data 
	else:
		Ps = INPUT.PointData["pressure"]                                                        # If the array contains absolute pressure values, then it reads the array data directly from input
    
	
 	# Read density data:
	if INPUT.GetPointData().HasArray("density")==0: 
		print "# TAU: Density array is not available in the input data. An incompressible flow will be assumed" 
		Rho = Rho0*Vx/Vx      																	#Vx/Vx creates a vector filled with "1"
	else:
		Rho = INPUT.PointData["density"]                                						# Density [Kg/m^3]

	
	# Read static temperature data:
	if INPUT.GetPointData().HasArray("temperature")==0:                                        	# This check if "TEMPERATURE" array does not exists in the input 
		print ""
		print "# TAU: Static Temperature array is not available in the input data"       		# It means that TEMPERATURE array does not exists (It may happen when energy equation is not activated in the RANS solution)
		print "# TAU: Static Temperature data is reconstructed from static pressure and density arrays"
		Ts = Ps/(R*Rho)                                                                        	# TEMPERATURE array is calculated from loaded data 
	else:
		Ts = INPUT.PointData["temperature"]                                                    	# If the array exists, then reads the array data directly from input
	 

	
	MU_LAM = INPUT.PointData["viscosity"] 														# Molecular viscosity [Kg/m*s]
	MU_TURB = INPUT.PointData["eddy_viscosity"]                            						# Turbulent viscosity [Kg/m*s]	
	
	MU_EFF = MU_LAM + MU_TURB                                               					# Effective viscosity [Kg/m*s]

	# Effective dissipation:
	Prt = 0.7     #IMPORTANT --> A STRONG HYPOTESIS IS MADE HERE (Pr=0.7) because no Prandtl number data available in the TAU file format
	Keff = CpGas*((MU_LAM/0.7)+(MU_TURB/Prt))

	return POINTS,Vx,Vy,Vz,Ps,Ts,Rho,MU_LAM,MU_TURB,MU_EFF,Keff