# -*- coding: utf-8 -*-
"""
############################################################################################################
#############################                     EPSILON                      #############################
#############################                 elsA CGNS reader                 #############################
############################################################################################################

# Abstract:
This python code is a module of the "Epsilon Aero Data" plugin that reads some variables from a elsA file
exported into the CGNS format.


# Disclaimer:
This plugin was developed for research purposes and released under GNU GPL V3 license without any guarantee
of any kind, either express or implied. Its use for teaching, research and industrial applications is allowed
under the strict responsibility of the user. The authors of this plugin are not responsible for any damages
or errors related to the use of the plugin.
"""


############################################################################################################
############################################### MODULES LOAD ###############################################
############################################################################################################

# We load the Python and Paraview standard modules:
import numpy as np
import vtk
from vtk.numpy_interface import algorithms as algs


############################################################################################################
######################################## ELSA CGNS READER FUNCTION #########################################
############################################################################################################

def Reader_elsA_CGNS_BC(INPUT,R,CvGas,CpGas,Ps0,Rho0,Ts0):
    
    # Reading aero data from Fluent file:
	POINTS = INPUT.Points   												# It takes the points coordinates
	Rho = INPUT.PointData["Density"]                              			# Density [Kg/m^3]
	MomentumX = INPUT.PointData["Momentum"][:,0]                    		# x-momentum: defined as Rho*u*u	
	MomentumY = INPUT.PointData["Momentum"][:,1]                    		# y-momentum: defined as Rho*u*v
	MomentumZ = INPUT.PointData["Momentum"][:,2]                    		# z-momentum: defined as Rho*u*w
	Ps = INPUT.PointData["Pressure"]   										# Static pressure 
	Ts = INPUT.PointData["Temperature"]   									# Static temperature
	MU_TURB_LAM_RATIO = INPUT.PointData["Viscosity_EddyMolecularRatio"]    
	
	Vx = algs.sqrt(MomentumX/Rho)
	Vy = MomentumY/(Rho*Vx)
	Vz = MomentumZ/(Rho*Vx)
	MU_LAM = (0.000001458*Ts**1.5)/(Ts+110.4)   							# Two-coefficient Sutherland equation
	MU_TURB = MU_TURB_LAM_RATIO*MU_LAM
	MU_EFF = MU_LAM + MU_TURB
	# Effective dissipation:
	Prt = 0.7     #IMPORTANT --> A STRONG HYPOTESIS IS MADE HERE (Pr=0.7) because no Prandtl number data available on elsA file format
	Keff = CpGas*((MU_LAM/0.7)+(MU_TURB/Prt))
	
	return POINTS,Vx,Vy,Vz,Ps,Ts,Rho,MU_LAM,MU_TURB,MU_EFF,Keff